DATA TOOL BOX
=====================

This is a python tool box project for handling global datasets. It contains the following features:

1. Augumented pandas DataFrames adding meta data
2. Automatic unit conversion and table based computations
3. ID based data structure

Authors:
Andreas Geiges  
Jonas Hörsch
Gaurav Ganti

Dependencies
------------
- pandas>=1.0.0,<1.1
- numpy
- gitpython
- openscm-units
- pint==0.11
- pycountry
- fuzzywuzzy
- tqdm
- matplotlib
- openpyxl
- pyam-iamc<=0.8.0
- hdx-python-country
- networkx>=2.4.0
- xarray
- deprecated

Installation via pip
--------------------


    pip install datatoolbox

Read the docs
-------------
https://datatoolbox.readthedocs.io/en/latest/

Testing
----------

From the root directory, run:

    pytest

